
# Slot: has gene


Each allele can be associated with any number of genes

URI: [biolink:sequence_variant_has_gene](https://w3id.org/biolink/vocab/sequence_variant_has_gene)


## Domain and Range

[SequenceVariant](SequenceVariant.md) &#8594;  <sub>0..\*</sub> [Gene](Gene.md)

## Parents

 *  is_a: [has gene](has_gene.md)

## Children


## Used by

 * [SequenceVariant](SequenceVariant.md)
 * [Snv](Snv.md)
